@@ -1,6 +1,6 @@
 // ------------------------------------------------------------------------
 // interface.cpp: Main user interface widget for ecamegapedal
-// Copyright (C) 2001,2002 Kai Vehmanen (kai.vehmanen@wakkanet.fi)
+// Copyright (C) 2001-2004 Kai Vehmanen (kai.vehmanen@wakkanet.fi)
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -58,7 +58,7 @@ QEInterface::QEInterface(QWidget *parent,
 			 const char *name)
   : QWidget(parent, name)
 {
-  setCaption("ecamegapedal v" + QString(ecamegapedal_version) + " - the real audio processor!");
+  setCaption("Ecamegapedal v" + QString(ecamegapedal_version) + " - the real audio processor!");
   qApp->setMainWidget(this);
 
   accel_repp = new QAccel(this);
@@ -67,17 +67,14 @@ QEInterface::QEInterface(QWidget *parent,
   ectrl_repp = new ECA_CONTROL(esession_repp);
   input_rep = "/dev/dsp";
   output_rep = "/dev/dsp";
-  io_changed_rep = false;
+  io_changed_rep = true; /* to trigger full_stop if start is issued 
+			    without first calling initialize() */
   srate_rep = 0;
   bufsize_rep = 0;
 
   fetch_defaults_from_jack();
 
   init_layout();
-  init_chainsetup();
-#ifdef ECA_COMPILE_JACK
-  start_processing(true);
-#endif
 }
 
 QEInterface::~QEInterface(void)
@@ -102,6 +99,13 @@ void QEInterface::fetch_defaults_from_jack(void)
 
   jack_set_error_function(ecamegapedal_jack_error_callback);
 
+  bool env_changed = false;
+  char* oldenv = getenv("JACK_NO_START_SERVER");
+  if (oldenv == NULL) {
+    env_changed = true;
+    setenv("JACK_NO_START_SERVER", "yes", 1);
+  }
+
   jack_client_t *client = jack_client_new (cname.c_str());
   if (client != 0) {
     srate_rep = jack_get_sample_rate(client);
@@ -117,6 +121,10 @@ void QEInterface::fetch_defaults_from_jack(void)
     output_rep = "jack_alsa";
   }
 
+  if (env_changed == true) {
+    unsetenv("JACK_NO_START_SERVER");
+  }
+
   DBC_CHECK(client == 0);
 #endif
 }
@@ -160,7 +168,7 @@ void QEInterface::init_bottomrow(QBoxLayout* bottomrow)
 void QEInterface::init_statusbar(void)
 {
   statusbar_repp = new QStatusBar(this, "qsbar");
-  statusbar_repp->message(QString("ecamegapedal v") + QString(ecamegapedal_version) + QString(" ready.")); 
+  statusbar_repp->message(QString("Ecamegapedal v") + QString(ecamegapedal_version) + QString(" ready.")); 
 
   QTimer *timer = new QTimer( this );
   connect( timer, SIGNAL(timeout()), this, SLOT(update_statusbar()));
@@ -182,7 +190,7 @@ void QEInterface::update_statusbar(void)
 			  last_epstatus.c_str() + 
 			  ", " + 
 			  QString(pos.c_str()) + 
-			  "sec ] . (C) 2001-2003 Kai Vehmanen");
+			  "sec ] . (C) 2001-2004 Kai Vehmanen");
 }
 
 void QEInterface::init_io_rows(void)
@@ -287,7 +295,7 @@ void QEInterface::init_buttons(void)
 
 }
 
-void QEInterface::init_chainsetup(void)
+void QEInterface::initialize(void)
 {
   /* make sure we're not running */
   if (ectrl_repp->is_connected() == true) stop_processing();
@@ -301,9 +309,7 @@ void QEInterface::init_chainsetup(void)
   ectrl_repp->add_chainsetup("ecamegapedal");
 
 #ifdef ECA_COMPILE_JACK
-#if ECA_LIBECASOUND_VERSION >= 10
-  ectrl_repp->set_chainsetup_parameter("-G:jack,ecamegapedal,sendrecv");
-#endif
+  ectrl_repp->command("cs-set-param -G:jack,ecamegapedal,sendrecv");
 #endif
 
   ectrl_repp->set_chainsetup_parameter("-B:rtlowlatency");
@@ -329,16 +335,16 @@ void QEInterface::start_processing(bool onlyengine)
 
   if (ectrl_repp->is_running() == true) ectrl_repp->stop_on_condition();
 
-  if (full_stop == true) init_chainsetup();
+  if (full_stop == true) initialize();
 
   ectrl_repp->select_chainsetup("ecamegapedal");
   ectrl_repp->select_chain("ecamegapedal");
 
   ectrl_repp->clear_chains();
 
+  /* create a new audiotrap object, ownership of the object
+     is transfered to libecasound */
   QEAudioTrap* atrap = new QEAudioTrap(this, 0, vumeter_repp);
-  // QObject::connect(atrap,        SIGNAL(dataUpdated(const SAMPLE_BUFFER*)), 
-  //  		      vumeter_repp, SLOT(dataUpdated(const SAMPLE_BUFFER*)));
 
   if (copinput_repp != 0) {
     copinput_repp->update_results();
@@ -348,8 +354,6 @@ void QEInterface::start_processing(bool onlyengine)
       for(int n = 0; n < new_c->number_of_params(); n++)
 	new_c->set_parameter(n + 1, c->get_parameter(n + 1));
 
-      // std::cerr << "(interface) new_expr\n";
-
       ectrl_repp->add_chain_operator(dynamic_cast<CHAIN_OPERATOR*>(new_c));
     }
   }
@@ -360,14 +364,14 @@ void QEInterface::start_processing(bool onlyengine)
   if (ectrl_repp->is_connected() == true && 
       ectrl_repp->is_running() != true) {
     if (onlyengine == true) {
-#if ECA_LIBECASOUND_VERSION >= 10
-      ectrl_repp->engine_start();
-#else
-      ectrl_repp->start();
-#endif
+      ectrl_repp->command("engine-launch");
+      if (ectrl_repp->last_type() == "e") {
+	/* libecasound v9 or older */
+	ectrl_repp->command("start");
+      }
     }
     else {
-      ectrl_repp->start();
+      ectrl_repp->command("start");
     }
   }
   else {
@@ -470,6 +474,16 @@ void QEInterface::button_rewind_begin(void) { ectrl_repp->command("setpos 0"); }
 void QEInterface::button_rewind(void) { ectrl_repp->command("rw 5"); }
 void QEInterface::button_forward(void) { ectrl_repp->command("fw 5"); }
 
+const string& QEInterface::input_name(void) const
+{
+  return(input_rep);
+}
+
+const string& QEInterface::output_name(void) const
+{
+  return(output_rep);
+}
+
 void QEInterface::set_input_name(const QString& q)
 {
   string s (q.latin1());
