@@ -18,11 +18,15 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 // ------------------------------------------------------------------------
 
+#include <iostream>
+
 #include "qevumeter.h"
 #include "qeaudiotrap.h"
 
+using std::cerr;
+using std::endl;
+
 QEAudioTrap::QEAudioTrap(QObject *parent, const char *name, QEVUMeter* target) 
-//    : QObject(parent,name) 
 {
   // initialize libecasound specific variables
   channels_rep = 0;
