@@ -2,26 +2,18 @@
 #define QEBUTTONROW_H
 
 #include <vector>
-
 #include <qwidget.h>
-#include <qlayout.h>
-#include <qaccel.h>
 #include <qfont.h>
 
-#include <kvutils/definition_by_contract.h>
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-#ifdef USE_CXX_STD_NAMESPACE
-using std::vector;
-#endif
+class QButton;
+class QAccel;
+class QHBoxLayout;
 
 /**
  * User-interface widget for representing a button-row. Supports
  * fonts and keyboard shortcuts.
  */
-class QEButtonRow : public QWidget, public DEFINITION_BY_CONTRACT {
+class QEButtonRow : public QWidget {
   Q_OBJECT
 
  public:
@@ -72,7 +64,7 @@ class QEButtonRow : public QWidget, public DEFINITION_BY_CONTRACT {
   QFont font_rep;
   QHBoxLayout* box;
   QAccel *accel;
-  vector<QButton*> buttons;
+  std::vector<QButton*> buttons;
 };
 
 #endif
