@@ -1,14 +1,19 @@
 #ifndef INCLUDED_QECHAINOPERATORINPUT_H
 #define INCLUDED_QECHAINOPERATORINPUT_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <vector>
 
 #include <qwidget.h>
 #include <qhbox.h>
 #include <qlineedit.h>
 
-#include <ecasound/eca-static-object-maps.h>
-#include <ecasound/eca-chainop.h>
+#include <eca-static-object-maps.h>
+#include <eca-chainop.h>
+#include <eca-version.h>
 
 #include "qeinput.h"
 
@@ -24,15 +29,25 @@ class QEEmptyChainOperator : public CHAIN_OPERATOR {
 
  public:
 
-  virtual string name(void) const { return("<none>"); }
-  virtual string parameter_names(void) const  { return(""); }
-  virtual void set_parameter(int param, parameter_type value) { }
+  virtual std::string name(void) const { return("<none>"); }
+  virtual std::string parameter_names(void) const  { return(""); }
+#if ECA_LIBECASOUND_VERSION > 7  
+  virtual parameter_t get_parameter(int param) const { return(0.0f); }
+  virtual void set_parameter(int param, CHAIN_OPERATOR::parameter_t value) { }
+#else
   virtual parameter_type get_parameter(int param) const { return(0.0f); }
+  virtual void set_parameter(int param, CHAIN_OPERATOR::parameter_type value) { }
+#endif
   virtual void init(SAMPLE_BUFFER *insample) { }
   virtual void process(void) { }
 
+#if ECA_LIBECASOUND_VERSION > 7
+  QEEmptyChainOperator* clone(void) const { return new QEEmptyChainOperator(*this); }
+  QEEmptyChainOperator* new_expr(void) const { return new QEEmptyChainOperator(); }
+#else
   QEEmptyChainOperator* clone(void)  { return new QEEmptyChainOperator(*this); }
   QEEmptyChainOperator* new_expr(void)  { return new QEEmptyChainOperator(); }
+#endif
 };
 
 /**
@@ -48,7 +63,7 @@ class QEChainOperatorInput : public QEInput {
   /**
    * Returns the resulting chain operator object instance
    */
-  CHAIN_OPERATOR* result(void) const { return(chainop_repp); }
+  const CHAIN_OPERATOR* result(void) const { return(chainop_repp); }
 
 public slots:
 
@@ -70,10 +85,10 @@ signals:
   CHAIN_OPERATOR* default_chainop_repp;
   QEOperatorConfiguration* opconf_repp;
   QTabWidget* maptab_rep;
-  vector<QEObjectMap*> omap_inputs;
+  std::vector<QEObjectMap*> omap_inputs;
   QLabel* cop_desc;
-  vector<QLabel*> paramlist;
-  vector<QLineEdit*> inputlist; 
+  std::vector<QLabel*> paramlist;
+  std::vector<QLineEdit*> inputlist; 
 
   /**
    * Creates and initializes widget layout
