@@ -1,14 +1,12 @@
-#ifndef _QEINPUT_H
-#define _QEINPUT_H
+#ifndef INCLUDED_QEINPUT_H
+#define INCLUDED_QEINPUT_H
 
 #include <qwidget.h>
-#include <kvutils/definition_by_contract.h>
 
 /**
  * A base class for libqtecasound input dialogs
  */
-class QEInput : public QWidget,
-		public DEFINITION_BY_CONTRACT {
+class QEInput : public QWidget {
   Q_OBJECT
 public:
 
