@@ -17,6 +17,10 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 // ------------------------------------------------------------------------
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <qaccel.h>
 #include <qlayout.h>
 #include <qlistbox.h>
@@ -26,14 +30,23 @@
 #include <qhbox.h>
 #include <qgrid.h>
 
+#include <iostream>
+#include <list>
+#include <map>
 #include <string>
 
-#include <ecasound/eca-object.h>
-#include <ecasound/eca-object-map.h>
+#include <eca-object.h>
+#include <eca-object-map.h>
+#include <eca-version.h>
 
+#include "dbc.h"
 #include "qeobjectmap.h"
 
-QEObjectMap::QEObjectMap (ECA_OBJECT_MAP* omap, QWidget *parent, const char *name) 
+using std::list;
+using std::map;
+using std::string;
+
+QEObjectMap::QEObjectMap (const ECA_OBJECT_MAP* omap, QWidget *parent, const char *name) 
   : QEInput(parent, name),
     omap_rep(omap) {
   init_layout();
@@ -49,10 +62,24 @@ void QEObjectMap::init_layout(void) {
 
   empty_rep = false;
   objlist->insertItem("<none>");
+
+#if ECA_LIBECASOUND_VERSION > 7
+  const list<string>& omap = omap_rep->registered_objects();
+  list<string>::const_iterator p = omap.begin();
+#else
   const map<string,string>& omap = omap_rep->registered_objects();
   map<string,string>::const_iterator p = omap.begin();
+#endif
   while(p != omap.end()) {
+#if ECA_LIBECASOUND_VERSION > 7
+    const ECA_OBJECT* obj = omap_rep->object(*p);
+    if (obj != 0) 
+      objlist->insertItem(obj->name().c_str());
+    else
+      objlist->insertItem(p->c_str());
+#else
     objlist->insertItem(p->second.c_str());
+#endif
     ++p;
   }
   if (omap.size() == 0) empty_rep = true;
@@ -67,18 +94,31 @@ void QEObjectMap::init_layout(void) {
 void QEObjectMap::update_results(void) {}
 void QEObjectMap::update_object(int index) {
   // --------
-  REQUIRE(index >= 0);
+  DBC_REQUIRE(index >= 0);
   // --------
 
   object_rep = 0;
-  const map<string,string>& omap = omap_rep->registered_objects();
 
+#if ECA_LIBECASOUND_VERSION > 7
+  const list<string>& omap = omap_rep->registered_objects();
+  list<string>::const_iterator p = omap.begin();
+#else
+  const map<string,string>& omap = omap_rep->registered_objects();
+  map<string,string>::const_iterator p = omap.begin();
+#endif
   if (index > 0) { /* the first object is always null */
     int counter = 1;
-    map<string,string>::const_iterator p = omap.begin();
     while(p != omap.end()) {
       if (counter == index) {
-	object_rep = dynamic_cast<ECA_OBJECT*>(omap_rep->object(p->first));
+#if ECA_LIBECASOUND_VERSION > 7
+	object_rep = dynamic_cast<const ECA_OBJECT*>(omap_rep->object(*p));
+#else
+	object_rep = dynamic_cast<const ECA_OBJECT*>(omap_rep->object(p->first, false));
+#endif
+	if (object_rep == 0) {
+	  //  std::cerr << "(qeobjectmap) creation failed; " << *p << ".\n";
+	  empty_rep = true;
+	}
 	emit changed();
       }
       ++p;
@@ -87,10 +127,11 @@ void QEObjectMap::update_object(int index) {
   }
   else {
     object_rep = 0;
+    empty_rep = true;
     emit changed();
   }
 
   // --------
-  ENSURE(object_rep != 0 || empty_rep == true);
+  DBC_ENSURE(object_rep != 0 || empty_rep == true);
   // --------
 }
